# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.computes_api import ComputesApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestComputesApi(unittest.TestCase):
    """ComputesApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.computes_api.ComputesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_compute(self):
        """Test case for create_compute

        """
        pass

    def test_delete_compute(self):
        """Test case for delete_compute

        """
        pass

    def test_edit_compute(self):
        """Test case for edit_compute

        """
        pass

    def test_get_compute_details(self):
        """Test case for get_compute_details

        """
        pass

    def test_list_type_computes(self):
        """Test case for list_type_computes

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.drive_api import DriveApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestDriveApi(unittest.TestCase):
    """DriveApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.drive_api.DriveApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_designates_drive_as_cache_drive(self):
        """Test case for designates_drive_as_cache_drive

        """
        pass

    def test_disable_drive(self):
        """Test case for disable_drive

        """
        pass

    def test_disable_drives_led(self):
        """Test case for disable_drives_led

        """
        pass

    def test_enable_drive(self):
        """Test case for enable_drive

        """
        pass

    def test_enable_drives_led(self):
        """Test case for enable_drives_led

        """
        pass

    def test_get_all_drives(self):
        """Test case for get_all_drives

        """
        pass

    def test_get_drive(self):
        """Test case for get_drive

        """
        pass

    def test_get_drive_smart(self):
        """Test case for get_drive_smart

        """
        pass

    def test_get_drive_smart_test_results(self):
        """Test case for get_drive_smart_test_results

        """
        pass

    def test_get_drives_details_end_location(self):
        """Test case for get_drives_details_end_location

        """
        pass

    def test_license_an_availiable_drive(self):
        """Test case for license_an_availiable_drive

        """
        pass

    def test_list_drive_comments(self):
        """Test case for list_drive_comments

        """
        pass

    def test_remove_drive(self):
        """Test case for remove_drive

        """
        pass

    def test_replace_allocated_drive(self):
        """Test case for replace_allocated_drive

        """
        pass

    def test_run_drive_smart_test(self):
        """Test case for run_drive_smart_test

        """
        pass

    def test_show_drives_metered_performane_information(self):
        """Test case for show_drives_metered_performane_information

        """
        pass

    def test_undesignate_drive_as_cache_drive(self):
        """Test case for undesignate_drive_as_cache_drive

        """
        pass

    def test_unlicense_an_availiable_drive(self):
        """Test case for unlicense_an_availiable_drive

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import Vpsa
from Vpsa.api.pools_api import PoolsApi  # noqa: E501
from Vpsa.rest import ApiException


class TestPoolsApi(unittest.TestCase):
    """PoolsApi unit test stubs"""

    def setUp(self):
        self.api = Vpsa.api.pools_api.PoolsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_shrink_pool(self):
        """Test case for cancel_shrink_pool

        """
        pass

    def test_create_pool(self):
        """Test case for create_pool

        """
        pass

    def test_delete_pool(self):
        """Test case for delete_pool

        """
        pass

    def test_expand_pool(self):
        """Test case for expand_pool

        """
        pass

    def test_get_all_pools(self):
        """Test case for get_all_pools

        """
        pass

    def test_get_pool(self):
        """Test case for get_pool

        """
        pass

    def test_get_pool_destination_volume_data(self):
        """Test case for get_pool_destination_volume_data

        """
        pass

    def test_get_pool_mirror_destination_volumes(self):
        """Test case for get_pool_mirror_destination_volumes

        """
        pass

    def test_get_pool_performance(self):
        """Test case for get_pool_performance

        """
        pass

    def test_get_raid_groups_in_pool(self):
        """Test case for get_raid_groups_in_pool

        """
        pass

    def test_get_volumes_in_pool(self):
        """Test case for get_volumes_in_pool

        """
        pass

    def test_get_volumes_in_pool_recycle_bin(self):
        """Test case for get_volumes_in_pool_recycle_bin

        """
        pass

    def test_rename_pool(self):
        """Test case for rename_pool

        """
        pass

    def test_set_pool_cache(self):
        """Test case for set_pool_cache

        """
        pass

    def test_set_pool_cowcache(self):
        """Test case for set_pool_cowcache

        """
        pass

    def test_shrink_pool(self):
        """Test case for shrink_pool

        """
        pass

    def test_update_pool_capacity_alerts(self):
        """Test case for update_pool_capacity_alerts

        """
        pass

    def test_update_ssd_cool_off(self):
        """Test case for update_ssd_cool_off

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse20038License(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'key': 'str',
        'active': 'bool',
        'temporary': 'bool',
        'disabled': 'bool',
        'licensed_drives': 'str',
        'total_drives': 'int',
        'expires': 'str',
        'first_activated': 'str',
        'last_activated': 'str',
        'next_activation': 'str',
        'message': 'str',
        'status': 'str',
        'badge_class': 'str'
    }

    attribute_map = {
        'key': 'key',
        'active': 'active',
        'temporary': 'temporary',
        'disabled': 'disabled',
        'licensed_drives': 'licensed_drives',
        'total_drives': 'total_drives',
        'expires': 'expires',
        'first_activated': 'first_activated',
        'last_activated': 'last_activated',
        'next_activation': 'next_activation',
        'message': 'message',
        'status': 'status',
        'badge_class': 'badge_class'
    }

    def __init__(self, key=None, active=None, temporary=None, disabled=None, licensed_drives=None, total_drives=None, expires=None, first_activated=None, last_activated=None, next_activation=None, message=None, status=None, badge_class=None, _configuration=None):  # noqa: E501
        """InlineResponse20038License - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._key = None
        self._active = None
        self._temporary = None
        self._disabled = None
        self._licensed_drives = None
        self._total_drives = None
        self._expires = None
        self._first_activated = None
        self._last_activated = None
        self._next_activation = None
        self._message = None
        self._status = None
        self._badge_class = None
        self.discriminator = None

        if key is not None:
            self.key = key
        if active is not None:
            self.active = active
        if temporary is not None:
            self.temporary = temporary
        if disabled is not None:
            self.disabled = disabled
        if licensed_drives is not None:
            self.licensed_drives = licensed_drives
        if total_drives is not None:
            self.total_drives = total_drives
        if expires is not None:
            self.expires = expires
        if first_activated is not None:
            self.first_activated = first_activated
        if last_activated is not None:
            self.last_activated = last_activated
        if next_activation is not None:
            self.next_activation = next_activation
        if message is not None:
            self.message = message
        if status is not None:
            self.status = status
        if badge_class is not None:
            self.badge_class = badge_class

    @property
    def key(self):
        """Gets the key of this InlineResponse20038License.  # noqa: E501


        :return: The key of this InlineResponse20038License.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this InlineResponse20038License.


        :param key: The key of this InlineResponse20038License.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def active(self):
        """Gets the active of this InlineResponse20038License.  # noqa: E501


        :return: The active of this InlineResponse20038License.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this InlineResponse20038License.


        :param active: The active of this InlineResponse20038License.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def temporary(self):
        """Gets the temporary of this InlineResponse20038License.  # noqa: E501


        :return: The temporary of this InlineResponse20038License.  # noqa: E501
        :rtype: bool
        """
        return self._temporary

    @temporary.setter
    def temporary(self, temporary):
        """Sets the temporary of this InlineResponse20038License.


        :param temporary: The temporary of this InlineResponse20038License.  # noqa: E501
        :type: bool
        """

        self._temporary = temporary

    @property
    def disabled(self):
        """Gets the disabled of this InlineResponse20038License.  # noqa: E501


        :return: The disabled of this InlineResponse20038License.  # noqa: E501
        :rtype: bool
        """
        return self._disabled

    @disabled.setter
    def disabled(self, disabled):
        """Sets the disabled of this InlineResponse20038License.


        :param disabled: The disabled of this InlineResponse20038License.  # noqa: E501
        :type: bool
        """

        self._disabled = disabled

    @property
    def licensed_drives(self):
        """Gets the licensed_drives of this InlineResponse20038License.  # noqa: E501


        :return: The licensed_drives of this InlineResponse20038License.  # noqa: E501
        :rtype: str
        """
        return self._licensed_drives

    @licensed_drives.setter
    def licensed_drives(self, licensed_drives):
        """Sets the licensed_drives of this InlineResponse20038License.


        :param licensed_drives: The licensed_drives of this InlineResponse20038License.  # noqa: E501
        :type: str
        """

        self._licensed_drives = licensed_drives

    @property
    def total_drives(self):
        """Gets the total_drives of this InlineResponse20038License.  # noqa: E501


        :return: The total_drives of this InlineResponse20038License.  # noqa: E501
        :rtype: int
        """
        return self._total_drives

    @total_drives.setter
    def total_drives(self, total_drives):
        """Sets the total_drives of this InlineResponse20038License.


        :param total_drives: The total_drives of this InlineResponse20038License.  # noqa: E501
        :type: int
        """

        self._total_drives = total_drives

    @property
    def expires(self):
        """Gets the expires of this InlineResponse20038License.  # noqa: E501


        :return: The expires of this InlineResponse20038License.  # noqa: E501
        :rtype: str
        """
        return self._expires

    @expires.setter
    def expires(self, expires):
        """Sets the expires of this InlineResponse20038License.


        :param expires: The expires of this InlineResponse20038License.  # noqa: E501
        :type: str
        """

        self._expires = expires

    @property
    def first_activated(self):
        """Gets the first_activated of this InlineResponse20038License.  # noqa: E501


        :return: The first_activated of this InlineResponse20038License.  # noqa: E501
        :rtype: str
        """
        return self._first_activated

    @first_activated.setter
    def first_activated(self, first_activated):
        """Sets the first_activated of this InlineResponse20038License.


        :param first_activated: The first_activated of this InlineResponse20038License.  # noqa: E501
        :type: str
        """

        self._first_activated = first_activated

    @property
    def last_activated(self):
        """Gets the last_activated of this InlineResponse20038License.  # noqa: E501


        :return: The last_activated of this InlineResponse20038License.  # noqa: E501
        :rtype: str
        """
        return self._last_activated

    @last_activated.setter
    def last_activated(self, last_activated):
        """Sets the last_activated of this InlineResponse20038License.


        :param last_activated: The last_activated of this InlineResponse20038License.  # noqa: E501
        :type: str
        """

        self._last_activated = last_activated

    @property
    def next_activation(self):
        """Gets the next_activation of this InlineResponse20038License.  # noqa: E501


        :return: The next_activation of this InlineResponse20038License.  # noqa: E501
        :rtype: str
        """
        return self._next_activation

    @next_activation.setter
    def next_activation(self, next_activation):
        """Sets the next_activation of this InlineResponse20038License.


        :param next_activation: The next_activation of this InlineResponse20038License.  # noqa: E501
        :type: str
        """

        self._next_activation = next_activation

    @property
    def message(self):
        """Gets the message of this InlineResponse20038License.  # noqa: E501


        :return: The message of this InlineResponse20038License.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this InlineResponse20038License.


        :param message: The message of this InlineResponse20038License.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def status(self):
        """Gets the status of this InlineResponse20038License.  # noqa: E501


        :return: The status of this InlineResponse20038License.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse20038License.


        :param status: The status of this InlineResponse20038License.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def badge_class(self):
        """Gets the badge_class of this InlineResponse20038License.  # noqa: E501


        :return: The badge_class of this InlineResponse20038License.  # noqa: E501
        :rtype: str
        """
        return self._badge_class

    @badge_class.setter
    def badge_class(self, badge_class):
        """Sets the badge_class of this InlineResponse20038License.


        :param badge_class: The badge_class of this InlineResponse20038License.  # noqa: E501
        :type: str
        """

        self._badge_class = badge_class

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20038License, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20038License):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20038License):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from CommandCenter.api_client import ApiClient


class CloudsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_cloud_vms_zsnap(self, create_cloud_vms_zsnap, **kwargs):  # noqa: E501
        """create_cloud_vms_zsnap  # noqa: E501

        Creates a Zsnap for the Command Center's Virtual Machine.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_cloud_vms_zsnap(create_cloud_vms_zsnap, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateCloudVmsZsnap create_cloud_vms_zsnap: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_cloud_vms_zsnap_with_http_info(create_cloud_vms_zsnap, **kwargs)  # noqa: E501
        else:
            (data) = self.create_cloud_vms_zsnap_with_http_info(create_cloud_vms_zsnap, **kwargs)  # noqa: E501
            return data

    def create_cloud_vms_zsnap_with_http_info(self, create_cloud_vms_zsnap, **kwargs):  # noqa: E501
        """create_cloud_vms_zsnap  # noqa: E501

        Creates a Zsnap for the Command Center's Virtual Machine.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_cloud_vms_zsnap_with_http_info(create_cloud_vms_zsnap, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateCloudVmsZsnap create_cloud_vms_zsnap: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['create_cloud_vms_zsnap']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_cloud_vms_zsnap" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'create_cloud_vms_zsnap' is set
        if self.api_client.client_side_validation and ('create_cloud_vms_zsnap' not in params or
                                                       params['create_cloud_vms_zsnap'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `create_cloud_vms_zsnap` when calling `create_cloud_vms_zsnap`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_cloud_vms_zsnap' in params:
            body_params = params['create_cloud_vms_zsnap']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/zsnap.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_clouds(self, **kwargs):  # noqa: E501
        """get_all_clouds  # noqa: E501

        Returns a list of all Zadara Storage Clouds which are managed by this Command Center.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_clouds(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: The page number to start from.
        :param int per_page: The total number of records to return.
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_clouds_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_clouds_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_clouds_with_http_info(self, **kwargs):  # noqa: E501
        """get_all_clouds  # noqa: E501

        Returns a list of all Zadara Storage Clouds which are managed by this Command Center.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_clouds_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: The page number to start from.
        :param int per_page: The total number of records to return.
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page', 'per_page']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_clouds" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'per_page' in params:
            query_params.append(('per_page', params['per_page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2001',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_cloud(self, name, **kwargs):  # noqa: E501
        """get_cloud  # noqa: E501

        Returns the details for a single Zadara Storage Cloud.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cloud(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :return: InlineResponse2002
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_cloud_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_cloud_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def get_cloud_with_http_info(self, name, **kwargs):  # noqa: E501
        """get_cloud  # noqa: E501

        Returns the details for a single Zadara Storage Cloud.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cloud_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :return: InlineResponse2002
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_cloud" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in params or
                                                       params['name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `name` when calling `get_cloud`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{name}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2002',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_redundancy_level_policies(self, cloud_name, **kwargs):  # noqa: E501
        """get_redundancy_level_policies  # noqa: E501

        Get cloud's zios storage policy types.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_redundancy_level_policies(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :return: InlineResponse2006
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_redundancy_level_policies_with_http_info(cloud_name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_redundancy_level_policies_with_http_info(cloud_name, **kwargs)  # noqa: E501
            return data

    def get_redundancy_level_policies_with_http_info(self, cloud_name, **kwargs):  # noqa: E501
        """get_redundancy_level_policies  # noqa: E501

        Get cloud's zios storage policy types.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_redundancy_level_policies_with_http_info(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :return: InlineResponse2006
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_redundancy_level_policies" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `get_redundancy_level_policies`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/vpsa_zone_group_storage_policy_types.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2006',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_cloud_public_ips(self, name, list_cloud_public_ips, **kwargs):  # noqa: E501
        """list_cloud_public_ips  # noqa: E501

        Returns a list of all of the cloud public IP's  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_cloud_public_ips(name, list_cloud_public_ips, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :param ListCloudPublicIps list_cloud_public_ips: (required)
        :return: InlineResponse2003
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_cloud_public_ips_with_http_info(name, list_cloud_public_ips, **kwargs)  # noqa: E501
        else:
            (data) = self.list_cloud_public_ips_with_http_info(name, list_cloud_public_ips, **kwargs)  # noqa: E501
            return data

    def list_cloud_public_ips_with_http_info(self, name, list_cloud_public_ips, **kwargs):  # noqa: E501
        """list_cloud_public_ips  # noqa: E501

        Returns a list of all of the cloud public IP's  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_cloud_public_ips_with_http_info(name, list_cloud_public_ips, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :param ListCloudPublicIps list_cloud_public_ips: (required)
        :return: InlineResponse2003
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'list_cloud_public_ips']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_cloud_public_ips" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in params or
                                                       params['name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `name` when calling `list_cloud_public_ips`")  # noqa: E501
        # verify the required parameter 'list_cloud_public_ips' is set
        if self.api_client.client_side_validation and ('list_cloud_public_ips' not in params or
                                                       params['list_cloud_public_ips'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `list_cloud_public_ips` when calling `list_cloud_public_ips`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'list_cloud_public_ips' in params:
            body_params = params['list_cloud_public_ips']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{name}/public_ips.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2003',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def rename_cloud(self, cloud_name, **kwargs):  # noqa: E501
        """rename_cloud  # noqa: E501

        Rename a Cloud.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rename_cloud(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str package:
        :param file settings_file: Settings file
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.rename_cloud_with_http_info(cloud_name, **kwargs)  # noqa: E501
        else:
            (data) = self.rename_cloud_with_http_info(cloud_name, **kwargs)  # noqa: E501
            return data

    def rename_cloud_with_http_info(self, cloud_name, **kwargs):  # noqa: E501
        """rename_cloud  # noqa: E501

        Rename a Cloud.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rename_cloud_with_http_info(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str package:
        :param file settings_file: Settings file
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'package', 'settings_file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method rename_cloud" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `rename_cloud`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'package' in params:
            form_params.append(('package', params['package']))  # noqa: E501
        if 'settings_file' in params:
            local_var_files['settings_file'] = params['settings_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/rename.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_cube_from_local_repo(self, cloud_name, set_cube_from_local_repo, **kwargs):  # noqa: E501
        """set_cube_from_local_repo  # noqa: E501

        Set cube package from the local repository.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_cube_from_local_repo(cloud_name, set_cube_from_local_repo, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param SetCubeFromLocalRepo set_cube_from_local_repo: (required)
        :return: InlineResponse2005
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_cube_from_local_repo_with_http_info(cloud_name, set_cube_from_local_repo, **kwargs)  # noqa: E501
        else:
            (data) = self.set_cube_from_local_repo_with_http_info(cloud_name, set_cube_from_local_repo, **kwargs)  # noqa: E501
            return data

    def set_cube_from_local_repo_with_http_info(self, cloud_name, set_cube_from_local_repo, **kwargs):  # noqa: E501
        """set_cube_from_local_repo  # noqa: E501

        Set cube package from the local repository.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_cube_from_local_repo_with_http_info(cloud_name, set_cube_from_local_repo, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param SetCubeFromLocalRepo set_cube_from_local_repo: (required)
        :return: InlineResponse2005
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'set_cube_from_local_repo']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_cube_from_local_repo" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `set_cube_from_local_repo`")  # noqa: E501
        # verify the required parameter 'set_cube_from_local_repo' is set
        if self.api_client.client_side_validation and ('set_cube_from_local_repo' not in params or
                                                       params['set_cube_from_local_repo'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `set_cube_from_local_repo` when calling `set_cube_from_local_repo`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'set_cube_from_local_repo' in params:
            body_params = params['set_cube_from_local_repo']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/set_cube.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2005',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def shutdown_cloud(self, cloud_name, **kwargs):  # noqa: E501
        """shutdown_cloud  # noqa: E501

        Shutdown a Cloud.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.shutdown_cloud(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.shutdown_cloud_with_http_info(cloud_name, **kwargs)  # noqa: E501
        else:
            (data) = self.shutdown_cloud_with_http_info(cloud_name, **kwargs)  # noqa: E501
            return data

    def shutdown_cloud_with_http_info(self, cloud_name, **kwargs):  # noqa: E501
        """shutdown_cloud  # noqa: E501

        Shutdown a Cloud.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.shutdown_cloud_with_http_info(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method shutdown_cloud" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `shutdown_cloud`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/shutdown.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upgrade_cloud(self, cloud_name, upgrade_cloud, **kwargs):  # noqa: E501
        """upgrade_cloud  # noqa: E501

        Upgrade a Cloud.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upgrade_cloud(cloud_name, upgrade_cloud, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param UpgradeCloud upgrade_cloud: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.upgrade_cloud_with_http_info(cloud_name, upgrade_cloud, **kwargs)  # noqa: E501
        else:
            (data) = self.upgrade_cloud_with_http_info(cloud_name, upgrade_cloud, **kwargs)  # noqa: E501
            return data

    def upgrade_cloud_with_http_info(self, cloud_name, upgrade_cloud, **kwargs):  # noqa: E501
        """upgrade_cloud  # noqa: E501

        Upgrade a Cloud.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upgrade_cloud_with_http_info(cloud_name, upgrade_cloud, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param UpgradeCloud upgrade_cloud: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'upgrade_cloud']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upgrade_cloud" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `upgrade_cloud`")  # noqa: E501
        # verify the required parameter 'upgrade_cloud' is set
        if self.api_client.client_side_validation and ('upgrade_cloud' not in params or
                                                       params['upgrade_cloud'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `upgrade_cloud` when calling `upgrade_cloud`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'upgrade_cloud' in params:
            body_params = params['upgrade_cloud']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/upgrade.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse20038Information(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bios_version': 'str',
        'system_manufacturer': 'str',
        'system_product_name': 'str',
        'system_serial_number': 'str',
        'baseboard_serial_number': 'str',
        'chassis_serial_number': 'str',
        'mr_info': 'InlineResponse20038InformationMrInfo',
        'cpu_infos': 'InlineResponse20038InformationCpuInfos',
        'uptime_since': 'str'
    }

    attribute_map = {
        'bios_version': 'bios_version',
        'system_manufacturer': 'system_manufacturer',
        'system_product_name': 'system_product_name',
        'system_serial_number': 'system_serial_number',
        'baseboard_serial_number': 'baseboard_serial_number',
        'chassis_serial_number': 'chassis_serial_number',
        'mr_info': 'mr_info',
        'cpu_infos': 'cpu_infos',
        'uptime_since': 'uptime_since'
    }

    def __init__(self, bios_version=None, system_manufacturer=None, system_product_name=None, system_serial_number=None, baseboard_serial_number=None, chassis_serial_number=None, mr_info=None, cpu_infos=None, uptime_since=None, _configuration=None):  # noqa: E501
        """InlineResponse20038Information - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._bios_version = None
        self._system_manufacturer = None
        self._system_product_name = None
        self._system_serial_number = None
        self._baseboard_serial_number = None
        self._chassis_serial_number = None
        self._mr_info = None
        self._cpu_infos = None
        self._uptime_since = None
        self.discriminator = None

        if bios_version is not None:
            self.bios_version = bios_version
        if system_manufacturer is not None:
            self.system_manufacturer = system_manufacturer
        if system_product_name is not None:
            self.system_product_name = system_product_name
        if system_serial_number is not None:
            self.system_serial_number = system_serial_number
        if baseboard_serial_number is not None:
            self.baseboard_serial_number = baseboard_serial_number
        if chassis_serial_number is not None:
            self.chassis_serial_number = chassis_serial_number
        if mr_info is not None:
            self.mr_info = mr_info
        if cpu_infos is not None:
            self.cpu_infos = cpu_infos
        if uptime_since is not None:
            self.uptime_since = uptime_since

    @property
    def bios_version(self):
        """Gets the bios_version of this InlineResponse20038Information.  # noqa: E501


        :return: The bios_version of this InlineResponse20038Information.  # noqa: E501
        :rtype: str
        """
        return self._bios_version

    @bios_version.setter
    def bios_version(self, bios_version):
        """Sets the bios_version of this InlineResponse20038Information.


        :param bios_version: The bios_version of this InlineResponse20038Information.  # noqa: E501
        :type: str
        """

        self._bios_version = bios_version

    @property
    def system_manufacturer(self):
        """Gets the system_manufacturer of this InlineResponse20038Information.  # noqa: E501


        :return: The system_manufacturer of this InlineResponse20038Information.  # noqa: E501
        :rtype: str
        """
        return self._system_manufacturer

    @system_manufacturer.setter
    def system_manufacturer(self, system_manufacturer):
        """Sets the system_manufacturer of this InlineResponse20038Information.


        :param system_manufacturer: The system_manufacturer of this InlineResponse20038Information.  # noqa: E501
        :type: str
        """

        self._system_manufacturer = system_manufacturer

    @property
    def system_product_name(self):
        """Gets the system_product_name of this InlineResponse20038Information.  # noqa: E501


        :return: The system_product_name of this InlineResponse20038Information.  # noqa: E501
        :rtype: str
        """
        return self._system_product_name

    @system_product_name.setter
    def system_product_name(self, system_product_name):
        """Sets the system_product_name of this InlineResponse20038Information.


        :param system_product_name: The system_product_name of this InlineResponse20038Information.  # noqa: E501
        :type: str
        """

        self._system_product_name = system_product_name

    @property
    def system_serial_number(self):
        """Gets the system_serial_number of this InlineResponse20038Information.  # noqa: E501


        :return: The system_serial_number of this InlineResponse20038Information.  # noqa: E501
        :rtype: str
        """
        return self._system_serial_number

    @system_serial_number.setter
    def system_serial_number(self, system_serial_number):
        """Sets the system_serial_number of this InlineResponse20038Information.


        :param system_serial_number: The system_serial_number of this InlineResponse20038Information.  # noqa: E501
        :type: str
        """

        self._system_serial_number = system_serial_number

    @property
    def baseboard_serial_number(self):
        """Gets the baseboard_serial_number of this InlineResponse20038Information.  # noqa: E501


        :return: The baseboard_serial_number of this InlineResponse20038Information.  # noqa: E501
        :rtype: str
        """
        return self._baseboard_serial_number

    @baseboard_serial_number.setter
    def baseboard_serial_number(self, baseboard_serial_number):
        """Sets the baseboard_serial_number of this InlineResponse20038Information.


        :param baseboard_serial_number: The baseboard_serial_number of this InlineResponse20038Information.  # noqa: E501
        :type: str
        """

        self._baseboard_serial_number = baseboard_serial_number

    @property
    def chassis_serial_number(self):
        """Gets the chassis_serial_number of this InlineResponse20038Information.  # noqa: E501


        :return: The chassis_serial_number of this InlineResponse20038Information.  # noqa: E501
        :rtype: str
        """
        return self._chassis_serial_number

    @chassis_serial_number.setter
    def chassis_serial_number(self, chassis_serial_number):
        """Sets the chassis_serial_number of this InlineResponse20038Information.


        :param chassis_serial_number: The chassis_serial_number of this InlineResponse20038Information.  # noqa: E501
        :type: str
        """

        self._chassis_serial_number = chassis_serial_number

    @property
    def mr_info(self):
        """Gets the mr_info of this InlineResponse20038Information.  # noqa: E501


        :return: The mr_info of this InlineResponse20038Information.  # noqa: E501
        :rtype: InlineResponse20038InformationMrInfo
        """
        return self._mr_info

    @mr_info.setter
    def mr_info(self, mr_info):
        """Sets the mr_info of this InlineResponse20038Information.


        :param mr_info: The mr_info of this InlineResponse20038Information.  # noqa: E501
        :type: InlineResponse20038InformationMrInfo
        """

        self._mr_info = mr_info

    @property
    def cpu_infos(self):
        """Gets the cpu_infos of this InlineResponse20038Information.  # noqa: E501


        :return: The cpu_infos of this InlineResponse20038Information.  # noqa: E501
        :rtype: InlineResponse20038InformationCpuInfos
        """
        return self._cpu_infos

    @cpu_infos.setter
    def cpu_infos(self, cpu_infos):
        """Sets the cpu_infos of this InlineResponse20038Information.


        :param cpu_infos: The cpu_infos of this InlineResponse20038Information.  # noqa: E501
        :type: InlineResponse20038InformationCpuInfos
        """

        self._cpu_infos = cpu_infos

    @property
    def uptime_since(self):
        """Gets the uptime_since of this InlineResponse20038Information.  # noqa: E501


        :return: The uptime_since of this InlineResponse20038Information.  # noqa: E501
        :rtype: str
        """
        return self._uptime_since

    @uptime_since.setter
    def uptime_since(self, uptime_since):
        """Sets the uptime_since of this InlineResponse20038Information.


        :param uptime_since: The uptime_since of this InlineResponse20038Information.  # noqa: E501
        :type: str
        """

        self._uptime_since = uptime_since

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20038Information, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20038Information):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20038Information):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from ProvisioningPortal.configuration import Configuration


class CreateVirtualNetwork(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'provider_id': 'str',
        'tenant_id': 'str',
        'gateway': 'str',
        'gateway_zone_1': 'str',
        'ipv6_gateway': 'str',
        'ipv6_gateway_zone_1': 'str',
        'cidr': 'str',
        'ipv6_cidr': 'str',
        'allocatable_ip_ranges': 'str',
        'ipv6_allocatable_ip_ranges': 'str',
        'vlan_id': 'int',
        'default_for_tenant': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'provider_id': 'provider_id',
        'tenant_id': 'tenant_id',
        'gateway': 'gateway',
        'gateway_zone_1': 'gateway_zone_1',
        'ipv6_gateway': 'ipv6_gateway',
        'ipv6_gateway_zone_1': 'ipv6_gateway_zone_1',
        'cidr': 'cidr',
        'ipv6_cidr': 'ipv6_cidr',
        'allocatable_ip_ranges': 'allocatable_ip_ranges',
        'ipv6_allocatable_ip_ranges': 'ipv6_allocatable_ip_ranges',
        'vlan_id': 'vlan_id',
        'default_for_tenant': 'default_for_tenant'
    }

    def __init__(self, name=None, provider_id=None, tenant_id=None, gateway=None, gateway_zone_1=None, ipv6_gateway=None, ipv6_gateway_zone_1=None, cidr=None, ipv6_cidr=None, allocatable_ip_ranges=None, ipv6_allocatable_ip_ranges=None, vlan_id=None, default_for_tenant=None, _configuration=None):  # noqa: E501
        """CreateVirtualNetwork - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._provider_id = None
        self._tenant_id = None
        self._gateway = None
        self._gateway_zone_1 = None
        self._ipv6_gateway = None
        self._ipv6_gateway_zone_1 = None
        self._cidr = None
        self._ipv6_cidr = None
        self._allocatable_ip_ranges = None
        self._ipv6_allocatable_ip_ranges = None
        self._vlan_id = None
        self._default_for_tenant = None
        self.discriminator = None

        self.name = name
        self.provider_id = provider_id
        self.tenant_id = tenant_id
        if gateway is not None:
            self.gateway = gateway
        if gateway_zone_1 is not None:
            self.gateway_zone_1 = gateway_zone_1
        if ipv6_gateway is not None:
            self.ipv6_gateway = ipv6_gateway
        if ipv6_gateway_zone_1 is not None:
            self.ipv6_gateway_zone_1 = ipv6_gateway_zone_1
        if cidr is not None:
            self.cidr = cidr
        if ipv6_cidr is not None:
            self.ipv6_cidr = ipv6_cidr
        if allocatable_ip_ranges is not None:
            self.allocatable_ip_ranges = allocatable_ip_ranges
        if ipv6_allocatable_ip_ranges is not None:
            self.ipv6_allocatable_ip_ranges = ipv6_allocatable_ip_ranges
        if vlan_id is not None:
            self.vlan_id = vlan_id
        if default_for_tenant is not None:
            self.default_for_tenant = default_for_tenant

    @property
    def name(self):
        """Gets the name of this CreateVirtualNetwork.  # noqa: E501


        :return: The name of this CreateVirtualNetwork.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateVirtualNetwork.


        :param name: The name of this CreateVirtualNetwork.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def provider_id(self):
        """Gets the provider_id of this CreateVirtualNetwork.  # noqa: E501


        :return: The provider_id of this CreateVirtualNetwork.  # noqa: E501
        :rtype: str
        """
        return self._provider_id

    @provider_id.setter
    def provider_id(self, provider_id):
        """Sets the provider_id of this CreateVirtualNetwork.


        :param provider_id: The provider_id of this CreateVirtualNetwork.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and provider_id is None:
            raise ValueError("Invalid value for `provider_id`, must not be `None`")  # noqa: E501

        self._provider_id = provider_id

    @property
    def tenant_id(self):
        """Gets the tenant_id of this CreateVirtualNetwork.  # noqa: E501


        :return: The tenant_id of this CreateVirtualNetwork.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this CreateVirtualNetwork.


        :param tenant_id: The tenant_id of this CreateVirtualNetwork.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and tenant_id is None:
            raise ValueError("Invalid value for `tenant_id`, must not be `None`")  # noqa: E501

        self._tenant_id = tenant_id

    @property
    def gateway(self):
        """Gets the gateway of this CreateVirtualNetwork.  # noqa: E501


        :return: The gateway of this CreateVirtualNetwork.  # noqa: E501
        :rtype: str
        """
        return self._gateway

    @gateway.setter
    def gateway(self, gateway):
        """Sets the gateway of this CreateVirtualNetwork.


        :param gateway: The gateway of this CreateVirtualNetwork.  # noqa: E501
        :type: str
        """

        self._gateway = gateway

    @property
    def gateway_zone_1(self):
        """Gets the gateway_zone_1 of this CreateVirtualNetwork.  # noqa: E501


        :return: The gateway_zone_1 of this CreateVirtualNetwork.  # noqa: E501
        :rtype: str
        """
        return self._gateway_zone_1

    @gateway_zone_1.setter
    def gateway_zone_1(self, gateway_zone_1):
        """Sets the gateway_zone_1 of this CreateVirtualNetwork.


        :param gateway_zone_1: The gateway_zone_1 of this CreateVirtualNetwork.  # noqa: E501
        :type: str
        """

        self._gateway_zone_1 = gateway_zone_1

    @property
    def ipv6_gateway(self):
        """Gets the ipv6_gateway of this CreateVirtualNetwork.  # noqa: E501


        :return: The ipv6_gateway of this CreateVirtualNetwork.  # noqa: E501
        :rtype: str
        """
        return self._ipv6_gateway

    @ipv6_gateway.setter
    def ipv6_gateway(self, ipv6_gateway):
        """Sets the ipv6_gateway of this CreateVirtualNetwork.


        :param ipv6_gateway: The ipv6_gateway of this CreateVirtualNetwork.  # noqa: E501
        :type: str
        """

        self._ipv6_gateway = ipv6_gateway

    @property
    def ipv6_gateway_zone_1(self):
        """Gets the ipv6_gateway_zone_1 of this CreateVirtualNetwork.  # noqa: E501


        :return: The ipv6_gateway_zone_1 of this CreateVirtualNetwork.  # noqa: E501
        :rtype: str
        """
        return self._ipv6_gateway_zone_1

    @ipv6_gateway_zone_1.setter
    def ipv6_gateway_zone_1(self, ipv6_gateway_zone_1):
        """Sets the ipv6_gateway_zone_1 of this CreateVirtualNetwork.


        :param ipv6_gateway_zone_1: The ipv6_gateway_zone_1 of this CreateVirtualNetwork.  # noqa: E501
        :type: str
        """

        self._ipv6_gateway_zone_1 = ipv6_gateway_zone_1

    @property
    def cidr(self):
        """Gets the cidr of this CreateVirtualNetwork.  # noqa: E501


        :return: The cidr of this CreateVirtualNetwork.  # noqa: E501
        :rtype: str
        """
        return self._cidr

    @cidr.setter
    def cidr(self, cidr):
        """Sets the cidr of this CreateVirtualNetwork.


        :param cidr: The cidr of this CreateVirtualNetwork.  # noqa: E501
        :type: str
        """

        self._cidr = cidr

    @property
    def ipv6_cidr(self):
        """Gets the ipv6_cidr of this CreateVirtualNetwork.  # noqa: E501


        :return: The ipv6_cidr of this CreateVirtualNetwork.  # noqa: E501
        :rtype: str
        """
        return self._ipv6_cidr

    @ipv6_cidr.setter
    def ipv6_cidr(self, ipv6_cidr):
        """Sets the ipv6_cidr of this CreateVirtualNetwork.


        :param ipv6_cidr: The ipv6_cidr of this CreateVirtualNetwork.  # noqa: E501
        :type: str
        """

        self._ipv6_cidr = ipv6_cidr

    @property
    def allocatable_ip_ranges(self):
        """Gets the allocatable_ip_ranges of this CreateVirtualNetwork.  # noqa: E501


        :return: The allocatable_ip_ranges of this CreateVirtualNetwork.  # noqa: E501
        :rtype: str
        """
        return self._allocatable_ip_ranges

    @allocatable_ip_ranges.setter
    def allocatable_ip_ranges(self, allocatable_ip_ranges):
        """Sets the allocatable_ip_ranges of this CreateVirtualNetwork.


        :param allocatable_ip_ranges: The allocatable_ip_ranges of this CreateVirtualNetwork.  # noqa: E501
        :type: str
        """

        self._allocatable_ip_ranges = allocatable_ip_ranges

    @property
    def ipv6_allocatable_ip_ranges(self):
        """Gets the ipv6_allocatable_ip_ranges of this CreateVirtualNetwork.  # noqa: E501


        :return: The ipv6_allocatable_ip_ranges of this CreateVirtualNetwork.  # noqa: E501
        :rtype: str
        """
        return self._ipv6_allocatable_ip_ranges

    @ipv6_allocatable_ip_ranges.setter
    def ipv6_allocatable_ip_ranges(self, ipv6_allocatable_ip_ranges):
        """Sets the ipv6_allocatable_ip_ranges of this CreateVirtualNetwork.


        :param ipv6_allocatable_ip_ranges: The ipv6_allocatable_ip_ranges of this CreateVirtualNetwork.  # noqa: E501
        :type: str
        """

        self._ipv6_allocatable_ip_ranges = ipv6_allocatable_ip_ranges

    @property
    def vlan_id(self):
        """Gets the vlan_id of this CreateVirtualNetwork.  # noqa: E501

        To automatically assign use \"vlan_id\":\"\"  # noqa: E501

        :return: The vlan_id of this CreateVirtualNetwork.  # noqa: E501
        :rtype: int
        """
        return self._vlan_id

    @vlan_id.setter
    def vlan_id(self, vlan_id):
        """Sets the vlan_id of this CreateVirtualNetwork.

        To automatically assign use \"vlan_id\":\"\"  # noqa: E501

        :param vlan_id: The vlan_id of this CreateVirtualNetwork.  # noqa: E501
        :type: int
        """

        self._vlan_id = vlan_id

    @property
    def default_for_tenant(self):
        """Gets the default_for_tenant of this CreateVirtualNetwork.  # noqa: E501


        :return: The default_for_tenant of this CreateVirtualNetwork.  # noqa: E501
        :rtype: bool
        """
        return self._default_for_tenant

    @default_for_tenant.setter
    def default_for_tenant(self, default_for_tenant):
        """Sets the default_for_tenant of this CreateVirtualNetwork.


        :param default_for_tenant: The default_for_tenant of this CreateVirtualNetwork.  # noqa: E501
        :type: bool
        """

        self._default_for_tenant = default_for_tenant

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateVirtualNetwork, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateVirtualNetwork):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateVirtualNetwork):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class CreateZcsContainer(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'imagename': 'str',
        'use_public_ip': 'str',
        'start': 'str',
        'volumes': 'list[str]',
        'ports': 'list[str]',
        'args': 'list[str]',
        'envvars': 'list[str]',
        'entrypoint': 'str',
        'link': 'list[str]',
        'memorypoolname': 'str'
    }

    attribute_map = {
        'name': 'name',
        'imagename': 'imagename',
        'use_public_ip': 'use_public_ip',
        'start': 'start',
        'volumes': 'volumes',
        'ports': 'ports',
        'args': 'args',
        'envvars': 'envvars',
        'entrypoint': 'entrypoint',
        'link': 'link',
        'memorypoolname': 'memorypoolname'
    }

    def __init__(self, name=None, imagename=None, use_public_ip=None, start=None, volumes=None, ports=None, args=None, envvars=None, entrypoint=None, link=None, memorypoolname=None, _configuration=None):  # noqa: E501
        """CreateZcsContainer - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._imagename = None
        self._use_public_ip = None
        self._start = None
        self._volumes = None
        self._ports = None
        self._args = None
        self._envvars = None
        self._entrypoint = None
        self._link = None
        self._memorypoolname = None
        self.discriminator = None

        self.name = name
        self.imagename = imagename
        self.use_public_ip = use_public_ip
        if start is not None:
            self.start = start
        if volumes is not None:
            self.volumes = volumes
        if ports is not None:
            self.ports = ports
        if args is not None:
            self.args = args
        if envvars is not None:
            self.envvars = envvars
        if entrypoint is not None:
            self.entrypoint = entrypoint
        if link is not None:
            self.link = link
        if memorypoolname is not None:
            self.memorypoolname = memorypoolname

    @property
    def name(self):
        """Gets the name of this CreateZcsContainer.  # noqa: E501

        A text label to assign to the ZCS container.  For example 'web-01', 'database', etc.  May not contain a single quote (') character.  Required.  # noqa: E501

        :return: The name of this CreateZcsContainer.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateZcsContainer.

        A text label to assign to the ZCS container.  For example 'web-01', 'database', etc.  May not contain a single quote (') character.  Required.  # noqa: E501

        :param name: The name of this CreateZcsContainer.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def imagename(self):
        """Gets the imagename of this CreateZcsContainer.  # noqa: E501


        :return: The imagename of this CreateZcsContainer.  # noqa: E501
        :rtype: str
        """
        return self._imagename

    @imagename.setter
    def imagename(self, imagename):
        """Sets the imagename of this CreateZcsContainer.


        :param imagename: The imagename of this CreateZcsContainer.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and imagename is None:
            raise ValueError("Invalid value for `imagename`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                imagename is not None and not re.search(r'^img-[0-9a-f]{8}$', imagename)):  # noqa: E501
            raise ValueError(r"Invalid value for `imagename`, must be a follow pattern or equal to `/^img-[0-9a-f]{8}$/`")  # noqa: E501

        self._imagename = imagename

    @property
    def use_public_ip(self):
        """Gets the use_public_ip of this CreateZcsContainer.  # noqa: E501

        If set to 'YES', the ZCS container will listen on VPSA's public IP address (only valid on VPSAs with a public IP address).  If set to 'NO', the container will listen on the same private IP address that is used for addressing the storage.  Optional (set to 'NO' by default).  # noqa: E501

        :return: The use_public_ip of this CreateZcsContainer.  # noqa: E501
        :rtype: str
        """
        return self._use_public_ip

    @use_public_ip.setter
    def use_public_ip(self, use_public_ip):
        """Sets the use_public_ip of this CreateZcsContainer.

        If set to 'YES', the ZCS container will listen on VPSA's public IP address (only valid on VPSAs with a public IP address).  If set to 'NO', the container will listen on the same private IP address that is used for addressing the storage.  Optional (set to 'NO' by default).  # noqa: E501

        :param use_public_ip: The use_public_ip of this CreateZcsContainer.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and use_public_ip is None:
            raise ValueError("Invalid value for `use_public_ip`, must not be `None`")  # noqa: E501

        self._use_public_ip = use_public_ip

    @property
    def start(self):
        """Gets the start of this CreateZcsContainer.  # noqa: E501

        If set to 'YES', the ZCS container will be started immediately after creation.  If 'NO', it will not be started. Required.  # noqa: E501

        :return: The start of this CreateZcsContainer.  # noqa: E501
        :rtype: str
        """
        return self._start

    @start.setter
    def start(self, start):
        """Sets the start of this CreateZcsContainer.

        If set to 'YES', the ZCS container will be started immediately after creation.  If 'NO', it will not be started. Required.  # noqa: E501

        :param start: The start of this CreateZcsContainer.  # noqa: E501
        :type: str
        """

        self._start = start

    @property
    def volumes(self):
        """Gets the volumes of this CreateZcsContainer.  # noqa: E501

        Volumes to attach to container (access_type:vol-name:path)  # noqa: E501

        :return: The volumes of this CreateZcsContainer.  # noqa: E501
        :rtype: list[str]
        """
        return self._volumes

    @volumes.setter
    def volumes(self, volumes):
        """Sets the volumes of this CreateZcsContainer.

        Volumes to attach to container (access_type:vol-name:path)  # noqa: E501

        :param volumes: The volumes of this CreateZcsContainer.  # noqa: E501
        :type: list[str]
        """

        self._volumes = volumes

    @property
    def ports(self):
        """Gets the ports of this CreateZcsContainer.  # noqa: E501

        Exposed ports  # noqa: E501

        :return: The ports of this CreateZcsContainer.  # noqa: E501
        :rtype: list[str]
        """
        return self._ports

    @ports.setter
    def ports(self, ports):
        """Sets the ports of this CreateZcsContainer.

        Exposed ports  # noqa: E501

        :param ports: The ports of this CreateZcsContainer.  # noqa: E501
        :type: list[str]
        """

        self._ports = ports

    @property
    def args(self):
        """Gets the args of this CreateZcsContainer.  # noqa: E501

        A Python list of Python dictionaries that contain arguments to pass to the ZCS container entry point program or script as defined by \"entrypoint\".  If passed as a string, a conversion to a Python list via json.loads will be attempted.  Every list item should be a dictionary that contains one key, \"arg\", whose value is the argument to pass to the ZCS container.  For example, if the entrypoint is \"/usr/sbin/sshd\" these arguments will be passed to sshd.  e.g. ' [{\"arg\":\"-p 2222\"},{\"arg\":\"-f /etc/ssh/sshd_config\"}]'  # noqa: E501

        :return: The args of this CreateZcsContainer.  # noqa: E501
        :rtype: list[str]
        """
        return self._args

    @args.setter
    def args(self, args):
        """Sets the args of this CreateZcsContainer.

        A Python list of Python dictionaries that contain arguments to pass to the ZCS container entry point program or script as defined by \"entrypoint\".  If passed as a string, a conversion to a Python list via json.loads will be attempted.  Every list item should be a dictionary that contains one key, \"arg\", whose value is the argument to pass to the ZCS container.  For example, if the entrypoint is \"/usr/sbin/sshd\" these arguments will be passed to sshd.  e.g. ' [{\"arg\":\"-p 2222\"},{\"arg\":\"-f /etc/ssh/sshd_config\"}]'  # noqa: E501

        :param args: The args of this CreateZcsContainer.  # noqa: E501
        :type: list[str]
        """

        self._args = args

    @property
    def envvars(self):
        """Gets the envvars of this CreateZcsContainer.  # noqa: E501

        Environment variables  # noqa: E501

        :return: The envvars of this CreateZcsContainer.  # noqa: E501
        :rtype: list[str]
        """
        return self._envvars

    @envvars.setter
    def envvars(self, envvars):
        """Sets the envvars of this CreateZcsContainer.

        Environment variables  # noqa: E501

        :param envvars: The envvars of this CreateZcsContainer.  # noqa: E501
        :type: list[str]
        """

        self._envvars = envvars

    @property
    def entrypoint(self):
        """Gets the entrypoint of this CreateZcsContainer.  # noqa: E501

        The full path to the program or script inside the ZCS container to run when the container starts.  For exmple \"/usr/local/bin/entry.sh\"  # noqa: E501

        :return: The entrypoint of this CreateZcsContainer.  # noqa: E501
        :rtype: str
        """
        return self._entrypoint

    @entrypoint.setter
    def entrypoint(self, entrypoint):
        """Sets the entrypoint of this CreateZcsContainer.

        The full path to the program or script inside the ZCS container to run when the container starts.  For exmple \"/usr/local/bin/entry.sh\"  # noqa: E501

        :param entrypoint: The entrypoint of this CreateZcsContainer.  # noqa: E501
        :type: str
        """

        self._entrypoint = entrypoint

    @property
    def link(self):
        """Gets the link of this CreateZcsContainer.  # noqa: E501

        A Python list that contain container identifiers that will be linked to the new container An example would be '[\"container-00000001\" , \"container-00000002\"]'  # noqa: E501

        :return: The link of this CreateZcsContainer.  # noqa: E501
        :rtype: list[str]
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this CreateZcsContainer.

        A Python list that contain container identifiers that will be linked to the new container An example would be '[\"container-00000001\" , \"container-00000002\"]'  # noqa: E501

        :param link: The link of this CreateZcsContainer.  # noqa: E501
        :type: list[str]
        """

        self._link = link

    @property
    def memorypoolname(self):
        """Gets the memorypoolname of this CreateZcsContainer.  # noqa: E501

        Container memory pool  # noqa: E501

        :return: The memorypoolname of this CreateZcsContainer.  # noqa: E501
        :rtype: str
        """
        return self._memorypoolname

    @memorypoolname.setter
    def memorypoolname(self, memorypoolname):
        """Sets the memorypoolname of this CreateZcsContainer.

        Container memory pool  # noqa: E501

        :param memorypoolname: The memorypoolname of this CreateZcsContainer.  # noqa: E501
        :type: str
        """

        self._memorypoolname = memorypoolname

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateZcsContainer, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateZcsContainer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateZcsContainer):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from Vpsa.api_client import ApiClient


class FileLifecycleApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_category(self, create_category, **kwargs):  # noqa: E501
        """create_category  # noqa: E501

        Create a new file lifecycle category with its file extensions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_category(create_category, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateCategory create_category: (required)
        :return: InlineResponse20041
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_category_with_http_info(create_category, **kwargs)  # noqa: E501
        else:
            (data) = self.create_category_with_http_info(create_category, **kwargs)  # noqa: E501
            return data

    def create_category_with_http_info(self, create_category, **kwargs):  # noqa: E501
        """create_category  # noqa: E501

        Create a new file lifecycle category with its file extensions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_category_with_http_info(create_category, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateCategory create_category: (required)
        :return: InlineResponse20041
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['create_category']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_category" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'create_category' is set
        if self.api_client.client_side_validation and ('create_category' not in params or
                                                       params['create_category'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `create_category` when calling `create_category`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_category' in params:
            body_params = params['create_category']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/flc/create_category.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20041',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_category(self, delete_category, **kwargs):  # noqa: E501
        """delete_category  # noqa: E501

        Delete a file lifecycle category.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_category(delete_category, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteCategory delete_category: (required)
        :return: InlineResponse20044
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_category_with_http_info(delete_category, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_category_with_http_info(delete_category, **kwargs)  # noqa: E501
            return data

    def delete_category_with_http_info(self, delete_category, **kwargs):  # noqa: E501
        """delete_category  # noqa: E501

        Delete a file lifecycle category.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_category_with_http_info(delete_category, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteCategory delete_category: (required)
        :return: InlineResponse20044
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['delete_category']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_category" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'delete_category' is set
        if self.api_client.client_side_validation and ('delete_category' not in params or
                                                       params['delete_category'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `delete_category` when calling `delete_category`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'delete_category' in params:
            body_params = params['delete_category']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/flc/delete_category.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20044',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_categories(self, **kwargs):  # noqa: E501
        """get_all_categories  # noqa: E501

        Show file lifecycle categories and their file extensions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_categories(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse20040
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_categories_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_categories_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_categories_with_http_info(self, **kwargs):  # noqa: E501
        """get_all_categories  # noqa: E501

        Show file lifecycle categories and their file extensions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_categories_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse20040
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_categories" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/flc/categories_settings.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20040',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_flc_data(self, resources, **kwargs):  # noqa: E501
        """get_flc_data  # noqa: E501

        get flc data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_flc_data(resources, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str resources: The resources_str is json string in the format:{chart_name:{name:<name>,type:<type>}} (required)
        :param int interval: The interval between data points, in seconds
        :param int count:
        :return: InlineResponse20045
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_flc_data_with_http_info(resources, **kwargs)  # noqa: E501
        else:
            (data) = self.get_flc_data_with_http_info(resources, **kwargs)  # noqa: E501
            return data

    def get_flc_data_with_http_info(self, resources, **kwargs):  # noqa: E501
        """get_flc_data  # noqa: E501

        get flc data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_flc_data_with_http_info(resources, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str resources: The resources_str is json string in the format:{chart_name:{name:<name>,type:<type>}} (required)
        :param int interval: The interval between data points, in seconds
        :param int count:
        :return: InlineResponse20045
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['resources', 'interval', 'count']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_flc_data" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'resources' is set
        if self.api_client.client_side_validation and ('resources' not in params or
                                                       params['resources'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `resources` when calling `get_flc_data`")  # noqa: E501

        if self.api_client.client_side_validation and ('interval' in params and params['interval'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `interval` when calling `get_flc_data`, must be a value greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('count' in params and params['count'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `count` when calling `get_flc_data`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501
        if 'resources' in params:
            query_params.append(('resources', params['resources']))  # noqa: E501
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/flc/flc_data.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20045',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def rename_category(self, rename_category, **kwargs):  # noqa: E501
        """rename_category  # noqa: E501

        Rename an existing file lifecycle category.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rename_category(rename_category, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RenameCategory rename_category: (required)
        :return: InlineResponse20043
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.rename_category_with_http_info(rename_category, **kwargs)  # noqa: E501
        else:
            (data) = self.rename_category_with_http_info(rename_category, **kwargs)  # noqa: E501
            return data

    def rename_category_with_http_info(self, rename_category, **kwargs):  # noqa: E501
        """rename_category  # noqa: E501

        Rename an existing file lifecycle category.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rename_category_with_http_info(rename_category, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RenameCategory rename_category: (required)
        :return: InlineResponse20043
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['rename_category']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method rename_category" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'rename_category' is set
        if self.api_client.client_side_validation and ('rename_category' not in params or
                                                       params['rename_category'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `rename_category` when calling `rename_category`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'rename_category' in params:
            body_params = params['rename_category']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/flc/rename_category.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20043',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_category(self, update_category, **kwargs):  # noqa: E501
        """update_category  # noqa: E501

        Update an existing file lifecycle category to change its file extensions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_category(update_category, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateCategory update_category: (required)
        :return: InlineResponse20042
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_category_with_http_info(update_category, **kwargs)  # noqa: E501
        else:
            (data) = self.update_category_with_http_info(update_category, **kwargs)  # noqa: E501
            return data

    def update_category_with_http_info(self, update_category, **kwargs):  # noqa: E501
        """update_category  # noqa: E501

        Update an existing file lifecycle category to change its file extensions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_category_with_http_info(update_category, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateCategory update_category: (required)
        :return: InlineResponse20042
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['update_category']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_category" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'update_category' is set
        if self.api_client.client_side_validation and ('update_category' not in params or
                                                       params['update_category'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `update_category` when calling `update_category`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_category' in params:
            body_params = params['update_category']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/flc/update_category.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20042',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import Zios
from Zios.api.users_api import UsersApi  # noqa: E501
from Zios.rest import ApiException


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self):
        self.api = Zios.api.users_api.UsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_new_user(self):
        """Test case for add_new_user

        """
        pass

    def test_change_password(self):
        """Test case for change_password

        """
        pass

    def test_change_user_pass_by_code(self):
        """Test case for change_user_pass_by_code

        """
        pass

    def test_change_user_role(self):
        """Test case for change_user_role

        """
        pass

    def test_delete_user(self):
        """Test case for delete_user

        """
        pass

    def test_disable_admin_access(self):
        """Test case for disable_admin_access

        """
        pass

    def test_disable_user(self):
        """Test case for disable_user

        """
        pass

    def test_enable_cloud_admin_access(self):
        """Test case for enable_cloud_admin_access

        """
        pass

    def test_enable_user(self):
        """Test case for enable_user

        """
        pass

    def test_get_all_users(self):
        """Test case for get_all_users

        """
        pass

    def test_get_auth_token(self):
        """Test case for get_auth_token

        """
        pass

    def test_get_user(self):
        """Test case for get_user

        """
        pass

    def test_issue_temp_code_to_mail(self):
        """Test case for issue_temp_code_to_mail

        """
        pass

    def test_reset_token(self):
        """Test case for reset_token

        """
        pass

    def test_reset_user_s3_keys(self):
        """Test case for reset_user_s3_keys

        """
        pass

    def test_show_bandwidth_throughput_metering_for_user(self):
        """Test case for show_bandwidth_throughput_metering_for_user

        """
        pass

    def test_show_iops_metring_of_user(self):
        """Test case for show_iops_metring_of_user

        """
        pass

    def test_show_latency_metering_of_user(self):
        """Test case for show_latency_metering_of_user

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import ProvisioningPortal
from ProvisioningPortal.api.vlan_api import VlanApi  # noqa: E501
from ProvisioningPortal.rest import ApiException


class TestVlanApi(unittest.TestCase):
    """VlanApi unit test stubs"""

    def setUp(self):
        self.api = ProvisioningPortal.api.vlan_api.VlanApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_alloacate_vlan(self):
        """Test case for alloacate_vlan

        """
        pass

    def test_deallocate_vlan(self):
        """Test case for deallocate_vlan

        """
        pass

    def test_list_availiable_vlan_for_provider(self):
        """Test case for list_availiable_vlan_for_provider

        """
        pass

    def test_list_availiable_vlans(self):
        """Test case for list_availiable_vlans

        """
        pass

    def test_set_vlan_as_default(self):
        """Test case for set_vlan_as_default

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class RestoreEncryptionPasswordKmip(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'host': 'str',
        'key_id': 'str',
        'key_name': 'str',
        'connect_via': 'str',
        'user': 'str',
        'password': 'str',
        'port': 'int',
        'version': 'str',
        'ca_cert_file': 'str',
        'proxy_host': 'str',
        'proxy_port': 'str',
        'proxy_username': 'str',
        'proxy_password': 'str',
        'key_file_content': 'str',
        'cert_file_content': 'str'
    }

    attribute_map = {
        'host': 'host',
        'key_id': 'key_id',
        'key_name': 'key_name',
        'connect_via': 'connect_via',
        'user': 'user',
        'password': 'password',
        'port': 'port',
        'version': 'version',
        'ca_cert_file': 'ca_cert_file',
        'proxy_host': 'proxy_host',
        'proxy_port': 'proxy_port',
        'proxy_username': 'proxy_username',
        'proxy_password': 'proxy_password',
        'key_file_content': 'key_file_content',
        'cert_file_content': 'cert_file_content'
    }

    def __init__(self, host=None, key_id=None, key_name=None, connect_via=None, user=None, password=None, port=None, version='3', ca_cert_file='/etc/ssl/certs/DigiCert_Global_Root_CA.pem', proxy_host=None, proxy_port=None, proxy_username=None, proxy_password=None, key_file_content=None, cert_file_content=None, _configuration=None):  # noqa: E501
        """RestoreEncryptionPasswordKmip - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._host = None
        self._key_id = None
        self._key_name = None
        self._connect_via = None
        self._user = None
        self._password = None
        self._port = None
        self._version = None
        self._ca_cert_file = None
        self._proxy_host = None
        self._proxy_port = None
        self._proxy_username = None
        self._proxy_password = None
        self._key_file_content = None
        self._cert_file_content = None
        self.discriminator = None

        self.host = host
        self.key_id = key_id
        self.key_name = key_name
        self.connect_via = connect_via
        self.user = user
        self.password = password
        if port is not None:
            self.port = port
        if version is not None:
            self.version = version
        if ca_cert_file is not None:
            self.ca_cert_file = ca_cert_file
        if proxy_host is not None:
            self.proxy_host = proxy_host
        if proxy_port is not None:
            self.proxy_port = proxy_port
        if proxy_username is not None:
            self.proxy_username = proxy_username
        if proxy_password is not None:
            self.proxy_password = proxy_password
        if key_file_content is not None:
            self.key_file_content = key_file_content
        if cert_file_content is not None:
            self.cert_file_content = cert_file_content

    @property
    def host(self):
        """Gets the host of this RestoreEncryptionPasswordKmip.  # noqa: E501

        The KMIP host to set.  # noqa: E501

        :return: The host of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this RestoreEncryptionPasswordKmip.

        The KMIP host to set.  # noqa: E501

        :param host: The host of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and host is None:
            raise ValueError("Invalid value for `host`, must not be `None`")  # noqa: E501

        self._host = host

    @property
    def key_id(self):
        """Gets the key_id of this RestoreEncryptionPasswordKmip.  # noqa: E501

        The KMIP key UUID to set.  # noqa: E501

        :return: The key_id of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :rtype: str
        """
        return self._key_id

    @key_id.setter
    def key_id(self, key_id):
        """Sets the key_id of this RestoreEncryptionPasswordKmip.

        The KMIP key UUID to set.  # noqa: E501

        :param key_id: The key_id of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and key_id is None:
            raise ValueError("Invalid value for `key_id`, must not be `None`")  # noqa: E501

        self._key_id = key_id

    @property
    def key_name(self):
        """Gets the key_name of this RestoreEncryptionPasswordKmip.  # noqa: E501

        The KMIP key name to set.  # noqa: E501

        :return: The key_name of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :rtype: str
        """
        return self._key_name

    @key_name.setter
    def key_name(self, key_name):
        """Sets the key_name of this RestoreEncryptionPasswordKmip.

        The KMIP key name to set.  # noqa: E501

        :param key_name: The key_name of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and key_name is None:
            raise ValueError("Invalid value for `key_name`, must not be `None`")  # noqa: E501

        self._key_name = key_name

    @property
    def connect_via(self):
        """Gets the connect_via of this RestoreEncryptionPasswordKmip.  # noqa: E501

        The KMIP connection interface.  # noqa: E501

        :return: The connect_via of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :rtype: str
        """
        return self._connect_via

    @connect_via.setter
    def connect_via(self, connect_via):
        """Sets the connect_via of this RestoreEncryptionPasswordKmip.

        The KMIP connection interface.  # noqa: E501

        :param connect_via: The connect_via of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and connect_via is None:
            raise ValueError("Invalid value for `connect_via`, must not be `None`")  # noqa: E501
        allowed_values = ["public", "fe"]  # noqa: E501
        if (self._configuration.client_side_validation and
                connect_via not in allowed_values):
            raise ValueError(
                "Invalid value for `connect_via` ({0}), must be one of {1}"  # noqa: E501
                .format(connect_via, allowed_values)
            )

        self._connect_via = connect_via

    @property
    def user(self):
        """Gets the user of this RestoreEncryptionPasswordKmip.  # noqa: E501

        The KMIP username, can be used for authentication.  # noqa: E501

        :return: The user of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this RestoreEncryptionPasswordKmip.

        The KMIP username, can be used for authentication.  # noqa: E501

        :param user: The user of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and user is None:
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501

        self._user = user

    @property
    def password(self):
        """Gets the password of this RestoreEncryptionPasswordKmip.  # noqa: E501

        The KMIP password, can be used for authentication.  # noqa: E501

        :return: The password of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this RestoreEncryptionPasswordKmip.

        The KMIP password, can be used for authentication.  # noqa: E501

        :param password: The password of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and password is None:
            raise ValueError("Invalid value for `password`, must not be `None`")  # noqa: E501

        self._password = password

    @property
    def port(self):
        """Gets the port of this RestoreEncryptionPasswordKmip.  # noqa: E501

        The KMIP host port to set.  # noqa: E501

        :return: The port of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this RestoreEncryptionPasswordKmip.

        The KMIP host port to set.  # noqa: E501

        :param port: The port of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :type: int
        """

        self._port = port

    @property
    def version(self):
        """Gets the version of this RestoreEncryptionPasswordKmip.  # noqa: E501

        The KMIP version to use:  0 (for unknown)  1 (for 1.0)  2 (for 1.1)  3 (for 1.2)  4 (for 1.3)  5 (for 1.4)  6 (for 2.0)  # noqa: E501

        :return: The version of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this RestoreEncryptionPasswordKmip.

        The KMIP version to use:  0 (for unknown)  1 (for 1.0)  2 (for 1.1)  3 (for 1.2)  4 (for 1.3)  5 (for 1.4)  6 (for 2.0)  # noqa: E501

        :param version: The version of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :type: str
        """
        allowed_values = ["0", "1", "2", "3", "4", "5", "6"]  # noqa: E501
        if (self._configuration.client_side_validation and
                version not in allowed_values):
            raise ValueError(
                "Invalid value for `version` ({0}), must be one of {1}"  # noqa: E501
                .format(version, allowed_values)
            )

        self._version = version

    @property
    def ca_cert_file(self):
        """Gets the ca_cert_file of this RestoreEncryptionPasswordKmip.  # noqa: E501

        The location of the CA certificate file on the VPSA file system.  # noqa: E501

        :return: The ca_cert_file of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :rtype: str
        """
        return self._ca_cert_file

    @ca_cert_file.setter
    def ca_cert_file(self, ca_cert_file):
        """Sets the ca_cert_file of this RestoreEncryptionPasswordKmip.

        The location of the CA certificate file on the VPSA file system.  # noqa: E501

        :param ca_cert_file: The ca_cert_file of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :type: str
        """

        self._ca_cert_file = ca_cert_file

    @property
    def proxy_host(self):
        """Gets the proxy_host of this RestoreEncryptionPasswordKmip.  # noqa: E501

        The proxy host, used if setting KMIP KMS with proxy.  # noqa: E501

        :return: The proxy_host of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :rtype: str
        """
        return self._proxy_host

    @proxy_host.setter
    def proxy_host(self, proxy_host):
        """Sets the proxy_host of this RestoreEncryptionPasswordKmip.

        The proxy host, used if setting KMIP KMS with proxy.  # noqa: E501

        :param proxy_host: The proxy_host of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :type: str
        """

        self._proxy_host = proxy_host

    @property
    def proxy_port(self):
        """Gets the proxy_port of this RestoreEncryptionPasswordKmip.  # noqa: E501

        The proxy port, used if setting KMIP KMS with proxy.  # noqa: E501

        :return: The proxy_port of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :rtype: str
        """
        return self._proxy_port

    @proxy_port.setter
    def proxy_port(self, proxy_port):
        """Sets the proxy_port of this RestoreEncryptionPasswordKmip.

        The proxy port, used if setting KMIP KMS with proxy.  # noqa: E501

        :param proxy_port: The proxy_port of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :type: str
        """

        self._proxy_port = proxy_port

    @property
    def proxy_username(self):
        """Gets the proxy_username of this RestoreEncryptionPasswordKmip.  # noqa: E501

        The proxy user name, used if setting KMIP KMS with authenticated proxy.  # noqa: E501

        :return: The proxy_username of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :rtype: str
        """
        return self._proxy_username

    @proxy_username.setter
    def proxy_username(self, proxy_username):
        """Sets the proxy_username of this RestoreEncryptionPasswordKmip.

        The proxy user name, used if setting KMIP KMS with authenticated proxy.  # noqa: E501

        :param proxy_username: The proxy_username of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :type: str
        """

        self._proxy_username = proxy_username

    @property
    def proxy_password(self):
        """Gets the proxy_password of this RestoreEncryptionPasswordKmip.  # noqa: E501

        The proxy password, used if setting KMIP KMS with authenticated proxy.  # noqa: E501

        :return: The proxy_password of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :rtype: str
        """
        return self._proxy_password

    @proxy_password.setter
    def proxy_password(self, proxy_password):
        """Sets the proxy_password of this RestoreEncryptionPasswordKmip.

        The proxy password, used if setting KMIP KMS with authenticated proxy.  # noqa: E501

        :param proxy_password: The proxy_password of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :type: str
        """

        self._proxy_password = proxy_password

    @property
    def key_file_content(self):
        """Gets the key_file_content of this RestoreEncryptionPasswordKmip.  # noqa: E501

        The private key file content, can be used for authentication.  # noqa: E501

        :return: The key_file_content of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :rtype: str
        """
        return self._key_file_content

    @key_file_content.setter
    def key_file_content(self, key_file_content):
        """Sets the key_file_content of this RestoreEncryptionPasswordKmip.

        The private key file content, can be used for authentication.  # noqa: E501

        :param key_file_content: The key_file_content of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :type: str
        """

        self._key_file_content = key_file_content

    @property
    def cert_file_content(self):
        """Gets the cert_file_content of this RestoreEncryptionPasswordKmip.  # noqa: E501

        The KMIP certificate file content, can be used for authentication.  # noqa: E501

        :return: The cert_file_content of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :rtype: str
        """
        return self._cert_file_content

    @cert_file_content.setter
    def cert_file_content(self, cert_file_content):
        """Sets the cert_file_content of this RestoreEncryptionPasswordKmip.

        The KMIP certificate file content, can be used for authentication.  # noqa: E501

        :param cert_file_content: The cert_file_content of this RestoreEncryptionPasswordKmip.  # noqa: E501
        :type: str
        """

        self._cert_file_content = cert_file_content

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RestoreEncryptionPasswordKmip, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RestoreEncryptionPasswordKmip):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RestoreEncryptionPasswordKmip):
            return True

        return self.to_dict() != other.to_dict()
